@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Notifier );
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 our $DEFAULT_UA = "Perl + " . __PACKAGE__ . "/$VERSION";
 our $DEFAULT_MAXREDIR = 3;
@@ -317,7 +317,8 @@ sub connect_connection
             write_len => $self->{write_len},
          );
 
-         $stream->read_handle->setsockopt( IPPROTO_IP, IP_TOS, $self->{ip_tos} ) if defined $self->{ip_tos};
+         # Defend against ->setsockopt doing silly things like detecting SvPOK()
+         $stream->read_handle->setsockopt( IPPROTO_IP, IP_TOS, $self->{ip_tos}+0 ) if defined $self->{ip_tos};
       },
 
       on_resolve_error => sub {
